@@ -1,5 +1,4 @@
-
-pub mod m1{
+pub mod m1 {
     pub fn f1() -> i32 {
         println!("edderocks1111111111111111");
         111
@@ -10,3 +9,8 @@ pub mod m1{
         222
     }
 }
+
+pub fn f3() -> i32 {
+    println!("fffffffffffffffffff333333333333333333333333");
+    333
+}
